Expr

Enum Expr 

pub enum Expr {
Show 52 variants Value(ValueExpr), Var(i32), Slot(i32), Neg(Box<NegExpr>), Bang(Box<NegExpr>), IsEmpty(Box<NegExpr>), Eq(Box<BinaryExpr>), Neq(Box<BinaryExpr>), In(Box<BinaryExpr>), Lt(Box<BinaryExpr>), Lte(Box<BinaryExpr>), Gt(Box<BinaryExpr>), Gte(Box<BinaryExpr>), And(Box<BinaryExpr>), Or(Box<BinaryExpr>), Plus(Box<BinaryExpr>), Minus(Box<BinaryExpr>), Mul(Box<BinaryExpr>), Contains(Box<BinaryExpr>), ContainsAll(Box<BinaryExpr>), ContainsAny(Box<BinaryExpr>), HasTag(Box<BinaryExpr>), GetTag(Box<BinaryExpr>), Has(Box<HasExpr>), Dot(Box<HasExpr>), Is(Box<IsExpr>), Like(Box<LikeExpr>), IfThenElse(Box<IfThenElseExpr>), Set(Set), Record(Record), Datetime(Set), Decimal(Set), Duration(Set), Ip(Set), IsIpV4(Set), IsIpV6(Set), IsLoopback(Set), IsMulticast(Set), IsInRange(Set), Offset(Set), DurationSince(Set), ToDate(Set), ToTime(Set), ToMilliseconds(Set), ToSeconds(Set), ToMinutes(Set), ToHours(Set), ToDays(Set), LessThan(Set), LessThanOrEqual(Set), GreaterThan(Set), GreaterThanOrEqual(Set),
}

Variants



Value(ValueExpr)



Var(i32)



Slot(i32)



Neg(Box<NegExpr>)



Bang(Box<NegExpr>)



IsEmpty(Box<NegExpr>)



Eq(Box<BinaryExpr>)



Neq(Box<BinaryExpr>)



In(Box<BinaryExpr>)



Lt(Box<BinaryExpr>)



Lte(Box<BinaryExpr>)



Gt(Box<BinaryExpr>)



Gte(Box<BinaryExpr>)



And(Box<BinaryExpr>)



Or(Box<BinaryExpr>)



Plus(Box<BinaryExpr>)



Minus(Box<BinaryExpr>)



Mul(Box<BinaryExpr>)



Contains(Box<BinaryExpr>)



ContainsAll(Box<BinaryExpr>)



ContainsAny(Box<BinaryExpr>)



HasTag(Box<BinaryExpr>)



GetTag(Box<BinaryExpr>)



Has(Box<HasExpr>)



Dot(Box<HasExpr>)



Is(Box<IsExpr>)



Like(Box<LikeExpr>)



IfThenElse(Box<IfThenElseExpr>)



Set(Set)



Record(Record)



Datetime(Set)



Decimal(Set)



Duration(Set)



Ip(Set)



IsIpV4(Set)



IsIpV6(Set)



IsLoopback(Set)



IsMulticast(Set)



IsInRange(Set)



Offset(Set)



DurationSince(Set)



ToDate(Set)



ToTime(Set)



ToMilliseconds(Set)



ToSeconds(Set)



ToMinutes(Set)



ToHours(Set)



ToDays(Set)



LessThan(Set)



LessThanOrEqual(Set)



GreaterThan(Set)



GreaterThanOrEqual(Set)

Implementations

Source

impl Expr

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<Expr>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.