pub struct BinaryExpr {
pub left: Option<Box<JsonExpr>>,
pub right: Option<Box<JsonExpr>>,
}Fields
left: Option<Box<JsonExpr>>right: Option<Box<JsonExpr>>Trait Implementations
Sourceimpl Clone for BinaryExpr
impl Clone for BinaryExpr
Sourcefn clone(&self) -> BinaryExpr
fn clone(&self) -> BinaryExpr
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BinaryExpr
impl Debug for BinaryExpr
Sourceimpl Default for BinaryExpr
impl Default for BinaryExpr
Sourceimpl From<BinaryExpr> for BinaryExpr
impl From<BinaryExpr> for BinaryExpr
Sourcefn from(value: BinaryExpr) -> Self
fn from(value: BinaryExpr) -> Self
Converts to this type from the input type.
Sourceimpl From<BinaryExpr> for BinaryExpr
impl From<BinaryExpr> for BinaryExpr
Sourcefn from(val: BinaryExpr) -> Self
fn from(val: BinaryExpr) -> Self
Converts to this type from the input type.
Sourceimpl Message for BinaryExpr
impl Message for BinaryExpr
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BinaryExpr
impl PartialEq for BinaryExpr
impl StructuralPartialEq for BinaryExpr