pub struct IfThenElseExpr {
pub if: Option<Box<JsonExpr>>,
pub then: Option<Box<JsonExpr>>,
pub else: Option<Box<JsonExpr>>,
}Fields
if: Option<Box<JsonExpr>>then: Option<Box<JsonExpr>>else: Option<Box<JsonExpr>>Trait Implementations
Sourceimpl Clone for IfThenElseExpr
impl Clone for IfThenElseExpr
Sourcefn clone(&self) -> IfThenElseExpr
fn clone(&self) -> IfThenElseExpr
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IfThenElseExpr
impl Debug for IfThenElseExpr
Sourceimpl Default for IfThenElseExpr
impl Default for IfThenElseExpr
Sourceimpl From<IfThenElseExpr> for IfThenElseExpr
impl From<IfThenElseExpr> for IfThenElseExpr
Sourcefn from(value: IfThenElseExpr) -> Self
fn from(value: IfThenElseExpr) -> Self
Converts to this type from the input type.
Sourceimpl From<IfThenElseExpr> for IfThenElseExpr
impl From<IfThenElseExpr> for IfThenElseExpr
Sourcefn from(val: IfThenElseExpr) -> Self
fn from(val: IfThenElseExpr) -> Self
Converts to this type from the input type.
Sourceimpl Message for IfThenElseExpr
impl Message for IfThenElseExpr
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for IfThenElseExpr
impl PartialEq for IfThenElseExpr
impl StructuralPartialEq for IfThenElseExpr